@@ -27,6 +27,7 @@
 
 #include "ptyxis-action-group.h"
 #include "ptyxis-application.h"
+#include "ptyxis-build-ident.h"
 #include "ptyxis-client.h"
 #include "ptyxis-container-menu.h"
 #include "ptyxis-preferences-window.h"
@@ -54,6 +55,7 @@ struct _PtyxisApplication
   GVariant            *session;
   guint                has_restored_session : 1;
   guint                overlay_scrollbars : 1;
+  guint                client_is_fallback : 1;
 };
 
 static void ptyxis_application_about             (GSimpleAction *action,
@@ -607,6 +609,8 @@ ptyxis_application_startup (GApplication *application)
   if (!(self->client = ptyxis_client_new (sandbox_agent, &error)) ||
       !ptyxis_client_ping (self->client, &error))
     {
+      self->client_is_fallback = TRUE;
+
       /* Try again, but launching inside our own Flatpak namespace. This
        * can happen when the host system does not have glibc. We may not
        * provide as good of an experience, but try nonetheless.
@@ -874,8 +878,13 @@ generate_debug_info (PtyxisApplication *self)
   guint n_items;
   guint id = 0;
 
+  g_string_append_printf (str, "%s %s (%s)\n",
+                          ptyxis_app_name (),
+                          PACKAGE_VERSION,
+                          PTYXIS_BUILD_IDENTIFIER);
+  g_string_append_c (str, '\n');
 
-  g_string_append_printf (str, "Name: %s\n", os_name);
+  g_string_append_printf (str, "Operating System: %s\n", os_name);
   g_string_append_c (str, '\n');
 
   if (uname (&u) == 0)
@@ -886,6 +895,11 @@ generate_debug_info (PtyxisApplication *self)
       g_string_append_printf (str, "uname.machine = %s\n", u.machine);
     }
 
+  g_string_append_c (str, '\n');
+  g_string_append_printf (str,
+                          "Agent: running %s\n",
+                          self->client_is_fallback ? "in sandbox" : "on host");
+
   g_string_append_c (str, '\n');
   g_string_append_printf (str,
                           "GLib: %d.%d.%d (compiled against %d.%d.%d)\n",
